import { access, constants, mkdir, writeFile } from 'fs/promises';
export const sleep = (ms = 1000) => new Promise(res => setTimeout(res, ms));
export async function path_exists(filepath) {
    try {
        await access(filepath, constants.R_OK | constants.W_OK);
        return true;
    }
    catch (err) {
        return false;
    }
}
export async function ensure_path(path) {
    if (!await path_exists(path)) {
        await mkdir(path);
    }
}
export async function ensure_file(filepath) {
    if (!await path_exists(filepath)) {
        await writeFile(filepath, '');
    }
}
export function convert_value(value) {
    return Math.round(value * 100_000_000);
}
export function convert_vout(vout) {
    return vout.map(e => {
        return { ...e, value: convert_value(e.value) };
    });
}
export function clone(data) {
    if (data === null)
        return null;
    if (typeof data === 'string')
        return String(data);
    if (typeof data === 'number')
        return Number(data);
    if (typeof data === 'bigint')
        return BigInt(data);
    if (typeof data === 'boolean')
        return Boolean(data);
    if (data instanceof Date) {
        return new Date(data.getTime());
    }
    if (Array.isArray(data)) {
        const arrCopy = [];
        data.forEach((val, i) => {
            arrCopy[i] = clone(val);
        });
        return arrCopy;
    }
    if (typeof data === 'object') {
        const objCopy = {};
        for (const key in data) {
            if (data.hasOwnProperty(key)) {
                objCopy[key] = clone(data[key]);
            }
        }
        return objCopy;
    }
    throw new TypeError('Content type not supported: ' + typeof data);
}
//# sourceMappingURL=util.js.map